@@ -8,15 +8,19 @@ use Gimp::OO;
 sub net {
   # simple benchmark ;)
   
-  $img=Gimp::Image::new(600,300,RGB);
+  $img=new Gimp::Image(600,300,RGB);
+  # the is the same as $img = new Image(600,300,RGB)
+  
   $bg=$img->layer_new(30,20,RGB_IMAGE,"Background",100,NORMAL_MODE);
+  
   $img->add_layer($bg,1);
-  Gimp::Display::new($img);
+  
+  new Gimp::Display($img);
   
   for $i (0..255) {
-     Gimp::Palette::set_background([$i,255-$i,$i]);
-     gimp_edit_fill ($img,$bg);
-     Gimp::Display::displays_flush ();
+     Palette::set_background([$i,255-$i,$i]);
+     $img->edit_fill ($bg);
+     Display::displays_flush ();
   }
   
 #  Gimp::Net::server_quit;  # kill the gimp-perl-server-extension (ugly name)
